@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -132,7 +127,7 @@ protected:
 private:
     QPointer<QWidget> m_widget;
     QPointer<QWidget> m_oldPreceding;
-    QList<QWidget *> m_oldParentZOrder;
+    QWidgetList m_oldParentZOrder;
 };
 
 class QDESIGNER_SHARED_EXPORT RaiseWidgetCommand: public ChangeZOrderCommand
@@ -247,8 +242,8 @@ private:
     QPoint m_newPos;
     QPointer<QWidget> m_oldParentWidget;
     QPointer<QWidget> m_newParentWidget;
-    QList<QWidget *> m_oldParentList;
-    QList<QWidget *> m_oldParentZOrder;
+    QWidgetList m_oldParentList;
+    QWidgetList m_oldParentZOrder;
 };
 
 class QDESIGNER_SHARED_EXPORT ChangeFormLayoutItemRoleCommand : public QDesignerFormWindowCommand
@@ -301,12 +296,12 @@ class QDESIGNER_SHARED_EXPORT TabOrderCommand: public QDesignerFormWindowCommand
 public:
     explicit TabOrderCommand(QDesignerFormWindowInterface *formWindow);
 
-    void init(const QList<QWidget*> &newTabOrder);
+    void init(const QWidgetList &newTabOrder);
 
-    inline QList<QWidget*> oldTabOrder() const
+    inline QWidgetList oldTabOrder() const
     { return m_oldTabOrder; }
 
-    inline QList<QWidget*> newTabOrder() const
+    inline QWidgetList newTabOrder() const
     { return m_newTabOrder; }
 
     virtual void redo();
@@ -314,8 +309,8 @@ public:
 
 private:
     QDesignerMetaDataBaseItemInterface *m_widgetItem;
-    QList<QWidget*> m_oldTabOrder;
-    QList<QWidget*> m_newTabOrder;
+    QWidgetList m_oldTabOrder;
+    QWidgetList m_newTabOrder;
 };
 
 class QDESIGNER_SHARED_EXPORT PromoteToCustomWidgetCommand : public QDesignerFormWindowCommand
